@@ -289,7 +289,7 @@ This package provides the following methods:
 
 =head2 cast
 
-  cast(Str $kind) (Object | Undef)
+  cast(string $kind) (object | undef)
 
 The cast method converts L<"value"|Venus::Kind::Value> objects between
 different I<"value"> object types, based on the name of the type provided. This
@@ -461,7 +461,7 @@ I<Since C<0.08>>
 
 =head2 default
 
-  default() (Bool)
+  default() (boolean)
 
 The default method returns the default value, i.e. C<0>.
 
@@ -483,7 +483,7 @@ I<Since C<0.01>>
 
 =head2 eq
 
-  eq(Any $arg) (Bool)
+  eq(any $arg) (boolean)
 
 The eq method performs an I<"equals"> operation using the argument provided.
 
@@ -672,7 +672,7 @@ I<Since C<0.08>>
 
 =head2 ge
 
-  ge(Any $arg) (Bool)
+  ge(any $arg) (boolean)
 
 The ge method performs a I<"greater-than-or-equal-to"> operation using the
 argument provided.
@@ -844,7 +844,7 @@ I<Since C<0.08>>
 
 =head2 gele
 
-  gele(Any $arg1, Any $arg2) (Bool)
+  gele(any $arg1, any $arg2) (boolean)
 
 The gele method performs a I<"greater-than-or-equal-to"> operation on the 1st
 argument, and I<"lesser-than-or-equal-to"> operation on the 2nd argument.
@@ -1034,7 +1034,7 @@ I<Since C<0.08>>
 
 =head2 gt
 
-  gt(Any $arg) (Bool)
+  gt(any $arg) (boolean)
 
 The gt method performs a I<"greater-than"> operation using the argument provided.
 
@@ -1223,7 +1223,7 @@ I<Since C<0.08>>
 
 =head2 gtlt
 
-  gtlt(Any $arg1, Any $arg2) (Bool)
+  gtlt(any $arg1, any $arg2) (boolean)
 
 The gtlt method performs a I<"greater-than"> operation on the 1st argument, and
 I<"lesser-than"> operation on the 2nd argument.
@@ -1413,7 +1413,7 @@ I<Since C<0.08>>
 
 =head2 is_false
 
-  is_false() (Bool)
+  is_false() (boolean)
 
 The is_false method returns C<false> if the boolean is falsy, otherwise returns
 C<true>.
@@ -1436,7 +1436,7 @@ I<Since C<0.01>>
 
 =head2 is_true
 
-  is_true() (Bool)
+  is_true() (boolean)
 
 The is_true method returns C<true> if the boolean is truthy, otherwise returns
 C<false>.
@@ -1459,7 +1459,7 @@ I<Since C<0.01>>
 
 =head2 le
 
-  le(Any $arg) (Bool)
+  le(any $arg) (boolean)
 
 The le method performs a I<"lesser-than-or-equal-to"> operation using the
 argument provided.
@@ -1649,7 +1649,7 @@ I<Since C<0.08>>
 
 =head2 lt
 
-  lt(Any $arg) (Bool)
+  lt(any $arg) (boolean)
 
 The lt method performs a I<"lesser-than"> operation using the argument provided.
 
@@ -1838,7 +1838,7 @@ I<Since C<0.08>>
 
 =head2 ne
 
-  ne(Any $arg) (Bool)
+  ne(any $arg) (boolean)
 
 The ne method performs a I<"not-equal-to"> operation using the argument provided.
 
@@ -2027,7 +2027,7 @@ I<Since C<0.08>>
 
 =head2 negate
 
-  negate() (Bool)
+  negate() (boolean)
 
 The negate method returns C<true> if the boolean is falsy, otherwise returns
 C<false>.
@@ -2050,7 +2050,7 @@ I<Since C<0.01>>
 
 =head2 numified
 
-  numified() (Int)
+  numified() (number)
 
 The numified method returns the numerical representation of the object.
 
@@ -2104,7 +2104,7 @@ I<Since C<0.08>>
 
 =head2 string
 
-  string() (Str)
+  string() (string)
 
 The string method returns the word C<'true'> if the boolean is truthy,
 otherwise returns C<'false'>. This method was formerly named I<"type">.
@@ -2127,7 +2127,7 @@ I<Since C<0.08>>
 
 =head2 tv
 
-  tv(Any $arg) (Bool)
+  tv(any $arg) (boolean)
 
 The tv method performs a I<"type-and-value-equal-to"> operation using argument
 provided.
@@ -2339,15 +2339,15 @@ B<example 1>
 
 =over 4
 
-=item operation: C<(E<lt>)>
+=item operation: C<(!=)>
 
-This package overloads the C<E<lt>> operator.
+This package overloads the C<!=> operator.
 
 B<example 1>
 
   # given: synopsis;
 
-  my $result = $boolean < 1;
+  my $result = $boolean != 1;
 
   # 1
 
@@ -2355,15 +2355,15 @@ B<example 1>
 
 =over 4
 
-=item operation: C<(E<lt>=)>
+=item operation: C<(==)>
 
-This package overloads the C<E<lt>=> operator.
+This package overloads the C<==> operator.
 
 B<example 1>
 
   # given: synopsis;
 
-  my $result = $boolean <= 0;
+  my $result = $boolean == 0;
 
   # 1
 
@@ -2403,15 +2403,15 @@ B<example 1>
 
 =over 4
 
-=item operation: C<(!=)>
+=item operation: C<(E<lt>)>
 
-This package overloads the C<!=> operator.
+This package overloads the C<E<lt>> operator.
 
 B<example 1>
 
   # given: synopsis;
 
-  my $result = $boolean != 1;
+  my $result = $boolean < 1;
 
   # 1
 
@@ -2419,15 +2419,15 @@ B<example 1>
 
 =over 4
 
-=item operation: C<(==)>
+=item operation: C<(E<lt>=)>
 
-This package overloads the C<==> operator.
+This package overloads the C<E<lt>=> operator.
 
 B<example 1>
 
   # given: synopsis;
 
-  my $result = $boolean == 0;
+  my $result = $boolean <= 0;
 
   # 1
 
@@ -2505,7 +2505,7 @@ Awncorp, C<awncorp@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2000, Al Newkirk.
+Copyright (C) 2000, Awncorp, C<awncorp@cpan.org>.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Apache license version 2.0.
