@@ -140,7 +140,7 @@ This package provides the following methods:
 
 =head2 call
 
-  call(Any @data) (Any)
+  call(any @data) (any)
 
 The call method executes and returns the result of the code.
 
@@ -198,7 +198,7 @@ I<Since C<0.01>>
 
 =head2 cast
 
-  cast(Str $kind) (Object | Undef)
+  cast(string $kind) (object | undef)
 
 The cast method converts L<"value"|Venus::Kind::Value> objects between
 different I<"value"> object types, based on the name of the type provided. This
@@ -370,7 +370,7 @@ I<Since C<0.08>>
 
 =head2 compose
 
-  compose(CodeRef $code, Any @data) (CodeRef)
+  compose(coderef $code, any @data) (coderef)
 
 The compose method creates a code reference which executes the first argument
 (another code reference) using the result from executing the code as it's
@@ -401,7 +401,7 @@ I<Since C<0.01>>
 
 =head2 conjoin
 
-  conjoin(CodeRef $code) (CodeRef)
+  conjoin(coderef $code) (coderef)
 
 The conjoin method creates a code reference which execute the code and the
 argument in a logical AND operation having the code as the lvalue and the
@@ -435,7 +435,7 @@ I<Since C<0.01>>
 
 =head2 curry
 
-  curry(Any @data) (CodeRef)
+  curry(any @data) (coderef)
 
 The curry method returns a code reference which executes the code passing it
 the arguments and any additional parameters when executed.
@@ -464,7 +464,7 @@ I<Since C<0.01>>
 
 =head2 default
 
-  default() (CodeRef)
+  default() (coderef)
 
 The default method returns the default value, i.e. C<sub{}>.
 
@@ -486,7 +486,7 @@ I<Since C<0.01>>
 
 =head2 disjoin
 
-  disjoin(CodeRef $code) (CodeRef)
+  disjoin(coderef $code) (coderef)
 
 The disjoin method creates a code reference which execute the code and the
 argument in a logical OR operation having the code as the lvalue and the
@@ -520,7 +520,7 @@ I<Since C<0.01>>
 
 =head2 eq
 
-  eq(Any $arg) (Bool)
+  eq(any $arg) (boolean)
 
 The eq method performs an I<"equals"> operation using the argument provided.
 
@@ -691,7 +691,7 @@ I<Since C<0.08>>
 
 =head2 ge
 
-  ge(Any $arg) (Bool)
+  ge(any $arg) (boolean)
 
 The ge method performs a I<"greater-than-or-equal-to"> operation using the
 argument provided.
@@ -863,7 +863,7 @@ I<Since C<0.08>>
 
 =head2 gele
 
-  gele(Any $arg1, Any $arg2) (Bool)
+  gele(any $arg1, any $arg2) (boolean)
 
 The gele method performs a I<"greater-than-or-equal-to"> operation on the 1st
 argument, and I<"lesser-than-or-equal-to"> operation on the 2nd argument.
@@ -1035,7 +1035,7 @@ I<Since C<0.08>>
 
 =head2 gt
 
-  gt(Any $arg) (Bool)
+  gt(any $arg) (boolean)
 
 The gt method performs a I<"greater-than"> operation using the argument provided.
 
@@ -1206,7 +1206,7 @@ I<Since C<0.08>>
 
 =head2 gtlt
 
-  gtlt(Any $arg1, Any $arg2) (Bool)
+  gtlt(any $arg1, any $arg2) (boolean)
 
 The gtlt method performs a I<"greater-than"> operation on the 1st argument, and
 I<"lesser-than"> operation on the 2nd argument.
@@ -1378,7 +1378,7 @@ I<Since C<0.08>>
 
 =head2 le
 
-  le(Any $arg) (Bool)
+  le(any $arg) (boolean)
 
 The le method performs a I<"lesser-than-or-equal-to"> operation using the
 argument provided.
@@ -1550,7 +1550,7 @@ I<Since C<0.08>>
 
 =head2 lt
 
-  lt(Any $arg) (Bool)
+  lt(any $arg) (boolean)
 
 The lt method performs a I<"lesser-than"> operation using the argument provided.
 
@@ -1721,7 +1721,7 @@ I<Since C<0.08>>
 
 =head2 ne
 
-  ne(Any $arg) (Bool)
+  ne(any $arg) (boolean)
 
 The ne method performs a I<"not-equal-to"> operation using the argument provided.
 
@@ -1892,7 +1892,7 @@ I<Since C<0.08>>
 
 =head2 next
 
-  next(Any @data) (Any)
+  next(any @data) (any)
 
 The next method is an alias to the call method. The naming is especially useful
 (i.e. helps with readability) when used with closure-based iterators.
@@ -1919,7 +1919,7 @@ I<Since C<0.01>>
 
 =head2 rcurry
 
-  rcurry(Any @data) (CodeRef)
+  rcurry(any @data) (coderef)
 
 The rcurry method returns a code reference which executes the code passing it
 the any additional parameters and any arguments when executed.
@@ -1948,7 +1948,7 @@ I<Since C<0.01>>
 
 =head2 tv
 
-  tv(Any $arg) (Bool)
+  tv(any $arg) (boolean)
 
 The tv method performs a I<"type-and-value-equal-to"> operation using argument
 provided.
@@ -2148,7 +2148,7 @@ Awncorp, C<awncorp@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2000, Al Newkirk.
+Copyright (C) 2000, Awncorp, C<awncorp@cpan.org>.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Apache license version 2.0.
