@@ -154,7 +154,7 @@ This package provides the following methods:
 
 =head2 does
 
-  does(Str $name) (Bool)
+  does(string $name) (boolean)
 
 The does method returns true if the object is composed of the role provided.
 
@@ -187,7 +187,7 @@ I<Since C<1.00>>
 
 =head2 import
 
-  import(Any @args) (Any)
+  import(any @args) (any)
 
 The import method throws a fatal exception whenever the L<perlfunc/use>
 declaration is used with roles as they are meant to be consumed via the C<with>
@@ -211,7 +211,7 @@ I<Since C<2.91>>
 
 =head2 meta
 
-  meta() (Meta)
+  meta() (Venus::Meta)
 
 The meta method returns a L<Venus::Meta> objects which describes the package's
 configuration.
@@ -239,7 +239,7 @@ I<Since C<1.00>>
 
 =head2 unimport
 
-  unimport(Any @args) (Any)
+  unimport(any @args) (any)
 
 The unimport method invokes the C<UNIMPORT> lifecycle hook and is invoked
 whenever the L<perlfunc/no> declaration is used.
@@ -268,7 +268,7 @@ Awncorp, C<awncorp@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2000, Al Newkirk.
+Copyright (C) 2000, Awncorp, C<awncorp@cpan.org>.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Apache license version 2.0.
