@@ -255,7 +255,7 @@ This package provides the following methods:
 
 =head2 decode
 
-  decode(Str $text) (Any)
+  decode(string $text) (any)
 
 The decode method decodes the Perl string, sets the object value, and returns
 the decoded value.
@@ -278,7 +278,7 @@ I<Since C<0.01>>
 
 =head2 encode
 
-  encode() (Str)
+  encode() (string)
 
 The encode method encodes the objects value as a Perl string and returns the
 encoded string.
@@ -307,7 +307,7 @@ Awncorp, C<awncorp@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2000, Al Newkirk.
+Copyright (C) 2000, Awncorp, C<awncorp@cpan.org>.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Apache license version 2.0.
