@@ -62,16 +62,6 @@ sub build_self {
 
 # METHODS
 
-sub assertion {
-  my ($self) = @_;
-
-  my $assert = $self->SUPER::assertion;
-
-  $assert->clear->expression('hashref');
-
-  return $assert;
-}
-
 sub config {
   my ($self, $package) = @_;
 
@@ -334,7 +324,7 @@ This package provides the following methods:
 
 =head2 decode
 
-  decode(Str $json) (Any)
+  decode(string $json) (any)
 
 The decode method decodes the JSON string, sets the object value, and returns
 the decoded value.
@@ -357,7 +347,7 @@ I<Since C<0.01>>
 
 =head2 encode
 
-  encode() (Str)
+  encode() (string)
 
 The encode method encodes the objects value as a JSON string and returns the
 encoded string.
@@ -418,7 +408,7 @@ Awncorp, C<awncorp@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2000, Al Newkirk.
+Copyright (C) 2000, Awncorp, C<awncorp@cpan.org>.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Apache license version 2.0.
