@@ -66,11 +66,17 @@ sub append_with {
 sub assertion {
   my ($self) = @_;
 
-  my $assert = $self->SUPER::assertion;
+  my $assertion = $self->SUPER::assertion;
 
-  $assert->clear->expression('number | float');
+  $assertion->match('float')->format(sub{
+    (ref $self || $self)->new($_)
+  });
 
-  return $assert;
+  $assertion->match('number')->format(sub{
+    (ref $self || $self)->new($_)
+  });
+
+  return $assertion;
 }
 
 sub atan2 {
@@ -449,7 +455,7 @@ I<Since C<1.23>>
 
 =head2 append
 
-  append(Str @parts) (Str)
+  append(string @parts) (string)
 
 The append method appends arugments to the number.
 
@@ -471,7 +477,7 @@ I<Since C<1.23>>
 
 =head2 append_with
 
-  append_with(Str $delimiter, Str @parts) (Str)
+  append_with(string $delimiter, string @parts) (string)
 
 The append_with method appends arugments to the number using the delimiter
 provided.
@@ -520,7 +526,7 @@ I<Since C<0.01>>
 
 =head2 cast
 
-  cast(Str $kind) (Object | Undef)
+  cast(string $kind) (object | undef)
 
 The cast method converts L<"value"|Venus::Kind::Value> objects between
 different I<"value"> object types, based on the name of the type provided. This
@@ -692,7 +698,7 @@ I<Since C<0.08>>
 
 =head2 concat
 
-  concat(Str @parts) (Str)
+  concat(string @parts) (string)
 
 The concat method returns the number with the argument list appended to it.
 
@@ -718,7 +724,7 @@ I<Since C<1.23>>
 
 =head2 contains
 
-  contains(Str $expr) (Bool)
+  contains(string $expr) (boolean)
 
 The contains method searches the number for a substring or expression returns
 true or false if found.
@@ -890,7 +896,7 @@ I<Since C<1.23>>
 
 =head2 eq
 
-  eq(Any $arg) (Bool)
+  eq(any $arg) (boolean)
 
 The eq method performs an I<"equals"> operation using the argument provided.
 
@@ -1120,7 +1126,7 @@ I<Since C<0.01>>
 
 =head2 ge
 
-  ge(Any $arg) (Bool)
+  ge(any $arg) (boolean)
 
 The ge method performs a I<"greater-than-or-equal-to"> operation using the
 argument provided.
@@ -1292,7 +1298,7 @@ I<Since C<0.08>>
 
 =head2 gele
 
-  gele(Any $arg1, Any $arg2) (Bool)
+  gele(any $arg1, any $arg2) (boolean)
 
 The gele method performs a I<"greater-than-or-equal-to"> operation on the 1st
 argument, and I<"lesser-than-or-equal-to"> operation on the 2nd argument.
@@ -1464,7 +1470,7 @@ I<Since C<0.08>>
 
 =head2 gt
 
-  gt(Any $arg) (Bool)
+  gt(any $arg) (boolean)
 
 The gt method performs a I<"greater-than"> operation using the argument provided.
 
@@ -1635,7 +1641,7 @@ I<Since C<0.08>>
 
 =head2 gtlt
 
-  gtlt(Any $arg1, Any $arg2) (Bool)
+  gtlt(any $arg1, any $arg2) (boolean)
 
 The gtlt method performs a I<"greater-than"> operation on the 1st argument, and
 I<"lesser-than"> operation on the 2nd argument.
@@ -1807,7 +1813,7 @@ I<Since C<0.08>>
 
 =head2 hex
 
-  hex() (Str)
+  hex() (string)
 
 The hex method returns a hex string representing the value of the number.
 
@@ -1875,7 +1881,7 @@ I<Since C<0.01>>
 
 =head2 index
 
-  index(Str $substr, Int $start) (Num)
+  index(string $substr, number $start) (Num)
 
 The index method searches for the argument within the number and returns the
 position of the first occurrence of the argument.
@@ -1961,7 +1967,7 @@ I<Since C<0.01>>
 
 =head2 le
 
-  le(Any $arg) (Bool)
+  le(any $arg) (boolean)
 
 The le method performs a I<"lesser-than-or-equal-to"> operation using the
 argument provided.
@@ -2204,7 +2210,7 @@ I<Since C<1.23>>
 
 =head2 lt
 
-  lt(Any $arg) (Bool)
+  lt(any $arg) (boolean)
 
 The lt method performs a I<"lesser-than"> operation using the argument provided.
 
@@ -2457,7 +2463,7 @@ I<Since C<1.23>>
 
 =head2 ne
 
-  ne(Any $arg) (Bool)
+  ne(any $arg) (boolean)
 
 The ne method performs a I<"not-equal-to"> operation using the argument provided.
 
@@ -2736,7 +2742,7 @@ I<Since C<0.01>>
 
 =head2 prepend
 
-  prepend(Str @parts) (Str)
+  prepend(string @parts) (string)
 
 The prepend method prepends arugments to the number.
 
@@ -2758,7 +2764,7 @@ I<Since C<1.23>>
 
 =head2 prepend_with
 
-  prepend_with(Str $delimiter, Str @parts) (Str)
+  prepend_with(string $delimiter, string @parts) (string)
 
 The prepend_with method prepends arugments to the number using the delimiter
 provided.
@@ -2781,7 +2787,7 @@ I<Since C<1.23>>
 
 =head2 range
 
-  range() (ArrayRef)
+  range() (arrayref)
 
 The range method returns an array reference containing integer increasing values
 up-to or down-to the limit specified.
@@ -2824,7 +2830,7 @@ I<Since C<0.01>>
 
 =head2 repeat
 
-  repeat(Num $number, Str $delimiter) (Str)
+  repeat(Num $number, string $delimiter) (string)
 
 The repeat method repeats the number value N times based on the argument provided
 and returns a new concatenated number. Optionally, a delimiter can be provided
@@ -2966,7 +2972,7 @@ I<Since C<1.23>>
 
 =head2 substr
 
-  substr(Num $offset, Num $length, Str $replace) (Str)
+  substr(Num $offset, Num $length, string $replace) (string)
 
 The substr method calls the core L</substr> function with the object's number
 value. In list context returns the result and the subject.
@@ -3041,7 +3047,7 @@ I<Since C<1.23>>
 
 =head2 tv
 
-  tv(Any $arg) (Bool)
+  tv(any $arg) (boolean)
 
 The tv method performs a I<"type-and-value-equal-to"> operation using argument
 provided.
@@ -3219,7 +3225,7 @@ Awncorp, C<awncorp@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2000, Al Newkirk.
+Copyright (C) 2000, Awncorp, C<awncorp@cpan.org>.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Apache license version 2.0.
