@@ -118,7 +118,7 @@ This package provides the following methods:
 
 =head2 cast
 
-  cast(Str $kind) (Object | Undef)
+  cast(string $kind) (object | undef)
 
 The cast method converts L<"value"|Venus::Kind::Value> objects between
 different I<"value"> object types, based on the name of the type provided. This
@@ -290,7 +290,7 @@ I<Since C<0.08>>
 
 =head2 default
 
-  default() (Regexp)
+  default() (regexp)
 
 The default method returns the default value, i.e. C<qr//>.
 
@@ -312,7 +312,7 @@ I<Since C<0.01>>
 
 =head2 eq
 
-  eq(Any $arg) (Bool)
+  eq(any $arg) (boolean)
 
 The eq method performs an I<"equals"> operation using the argument provided.
 
@@ -483,7 +483,7 @@ I<Since C<0.08>>
 
 =head2 ge
 
-  ge(Any $arg) (Bool)
+  ge(any $arg) (boolean)
 
 The ge method performs a I<"greater-than-or-equal-to"> operation using the
 argument provided.
@@ -655,7 +655,7 @@ I<Since C<0.08>>
 
 =head2 gele
 
-  gele(Any $arg1, Any $arg2) (Bool)
+  gele(any $arg1, any $arg2) (boolean)
 
 The gele method performs a I<"greater-than-or-equal-to"> operation on the 1st
 argument, and I<"lesser-than-or-equal-to"> operation on the 2nd argument.
@@ -827,7 +827,7 @@ I<Since C<0.08>>
 
 =head2 gt
 
-  gt(Any $arg) (Bool)
+  gt(any $arg) (boolean)
 
 The gt method performs a I<"greater-than"> operation using the argument provided.
 
@@ -998,7 +998,7 @@ I<Since C<0.08>>
 
 =head2 gtlt
 
-  gtlt(Any $arg1, Any $arg2) (Bool)
+  gtlt(any $arg1, any $arg2) (boolean)
 
 The gtlt method performs a I<"greater-than"> operation on the 1st argument, and
 I<"lesser-than"> operation on the 2nd argument.
@@ -1170,7 +1170,7 @@ I<Since C<0.08>>
 
 =head2 le
 
-  le(Any $arg) (Bool)
+  le(any $arg) (boolean)
 
 The le method performs a I<"lesser-than-or-equal-to"> operation using the
 argument provided.
@@ -1342,7 +1342,7 @@ I<Since C<0.08>>
 
 =head2 lt
 
-  lt(Any $arg) (Bool)
+  lt(any $arg) (boolean)
 
 The lt method performs a I<"lesser-than"> operation using the argument provided.
 
@@ -1513,7 +1513,7 @@ I<Since C<0.08>>
 
 =head2 ne
 
-  ne(Any $arg) (Bool)
+  ne(any $arg) (boolean)
 
 The ne method performs a I<"not-equal-to"> operation using the argument provided.
 
@@ -1684,7 +1684,7 @@ I<Since C<0.08>>
 
 =head2 numified
 
-  numified() (Int)
+  numified() (number)
 
 The numified method returns the numerical representation of the object. For
 regexp objects the method returns the length (or character count) of the
@@ -1726,7 +1726,7 @@ I<Since C<0.08>>
 
 =head2 replace
 
-  replace(Str $string, Str $substr, Str $flags) (Replace)
+  replace(string $string, string $substr, string $flags) (Venus::Replace)
 
 The replace method performs a regular expression substitution on the given
 string. The first argument is the string to match against. The second argument
@@ -1759,7 +1759,7 @@ I<Since C<0.01>>
 
 =head2 search
 
-  search(Str $string) (Search)
+  search(string $string) (Venus::Search)
 
 The search method performs a regular expression match against the given string,
 this method will always return a L<Venus::Search> object which can be used to
@@ -1789,7 +1789,7 @@ I<Since C<0.01>>
 
 =head2 stringified
 
-  stringified() (Str)
+  stringified() (string)
 
 The stringified method returns the object, stringified (i.e. a dump of the
 object's value).
@@ -1833,7 +1833,7 @@ I<Since C<0.08>>
 
 =head2 tv
 
-  tv(Any $arg) (Bool)
+  tv(any $arg) (boolean)
 
 The tv method performs a I<"type-and-value-equal-to"> operation using argument
 provided.
@@ -2065,7 +2065,7 @@ Awncorp, C<awncorp@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2000, Al Newkirk.
+Copyright (C) 2000, Awncorp, C<awncorp@cpan.org>.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Apache license version 2.0.
