@@ -321,7 +321,7 @@ This package provides the following methods:
 
 =head2 captures
 
-  captures() (ArrayRef)
+  captures() (arrayref)
 
 The captures method returns the capture groups from the result object which
 contains information about the results of the regular expression operation.
@@ -345,7 +345,7 @@ I<Since C<0.01>>
 
 =head2 count
 
-  count() (Num)
+  count() (number)
 
 The count method returns the number of match occurrences from the result object
 which contains information about the results of the regular expression
@@ -369,7 +369,7 @@ I<Since C<0.01>>
 
 =head2 evaluate
 
-  evaluate() (ArrayRef)
+  evaluate() (arrayref)
 
 The evaluate method performs the regular expression operation and returns an
 arrayref representation of the results.
@@ -420,7 +420,7 @@ I<Since C<0.01>>
 
 =head2 explain
 
-  explain() (Str)
+  explain() (string)
 
 The explain method returns the subject of the regular expression operation and
 is used in stringification operations.
@@ -443,7 +443,7 @@ I<Since C<0.01>>
 
 =head2 get
 
-  get() (Str)
+  get() (string)
 
 The get method returns the subject of the regular expression operation.
 
@@ -465,7 +465,7 @@ I<Since C<0.01>>
 
 =head2 initial
 
-  initial() (Str)
+  initial() (string)
 
 The initial method returns the unaltered string from the result object which
 contains information about the results of the regular expression operation.
@@ -488,7 +488,7 @@ I<Since C<0.01>>
 
 =head2 last_match_end
 
-  last_match_end() (Maybe[ArrayRef[Int]])
+  last_match_end() (maybe[within[arrayref, number]])
 
 The last_match_end method returns an array of offset positions into the string
 where the capture(s) stopped matching from the result object which contains
@@ -512,7 +512,7 @@ I<Since C<0.01>>
 
 =head2 last_match_start
 
-  last_match_start() (Maybe[ArrayRef[Int]])
+  last_match_start() (maybe[within[arrayref, number]])
 
 The last_match_start method returns an array of offset positions into the
 string where the capture(s) matched from the result object which contains
@@ -536,7 +536,7 @@ I<Since C<0.01>>
 
 =head2 matched
 
-  matched() (Maybe[Str])
+  matched() (maybe[string])
 
 The matched method returns the portion of the string that matched from the
 result object which contains information about the results of the regular
@@ -560,7 +560,7 @@ I<Since C<0.01>>
 
 =head2 named_captures
 
-  named_captures() (HashRef)
+  named_captures() (hashref)
 
 The named_captures method returns a hash containing the requested named regular
 expressions and captured string pairs from the result object which contains
@@ -604,7 +604,7 @@ I<Since C<0.01>>
 
 =head2 postmatched
 
-  postmatched() (Maybe[Str)
+  postmatched() (Maybe[string])
 
 The postmatched method returns the portion of the string after the regular
 expression matched from the result object which contains information about the
@@ -628,7 +628,7 @@ I<Since C<0.01>>
 
 =head2 prematched
 
-  prematched() (Maybe[Str)
+  prematched() (Maybe[string])
 
 The prematched method returns the portion of the string before the regular
 expression matched from the result object which contains information about the
@@ -652,7 +652,7 @@ I<Since C<0.01>>
 
 =head2 set
 
-  set(Str $data) (Str)
+  set(string $data) (string)
 
 The set method sets the subject of the regular expression operation.
 
@@ -713,6 +713,30 @@ This package overloads the following operators:
 
 =over 4
 
+=item operation: C<("")>
+
+This package overloads the C<""> operator.
+
+B<example 1>
+
+  # given: synopsis;
+
+  my $result = "$replace";
+
+  # "hello universe"
+
+B<example 2>
+
+  # given: synopsis;
+
+  my $result = "$replace, $replace";
+
+  # "hello universe, hello universe"
+
+=back
+
+=over 4
+
 =item operation: C<(.)>
 
 This package overloads the C<.> operator.
@@ -777,30 +801,6 @@ B<example 1>
 
 =over 4
 
-=item operation: C<("")>
-
-This package overloads the C<""> operator.
-
-B<example 1>
-
-  # given: synopsis;
-
-  my $result = "$replace";
-
-  # "hello universe"
-
-B<example 2>
-
-  # given: synopsis;
-
-  my $result = "$replace, $replace";
-
-  # "hello universe, hello universe"
-
-=back
-
-=over 4
-
 =item operation: C<(~~)>
 
 This package overloads the C<~~> operator.
@@ -823,7 +823,7 @@ Awncorp, C<awncorp@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2000, Al Newkirk.
+Copyright (C) 2000, Awncorp, C<awncorp@cpan.org>.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Apache license version 2.0.
