@@ -101,7 +101,7 @@ This package provides the following methods:
 
 =head2 access
 
-  access(Str $name, Any $value) (Any)
+  access(string $name, any $value) (any)
 
 The access method gets or sets the class attribute specified.
 
@@ -175,7 +175,7 @@ I<Since C<1.23>>
 
 =head2 assign
 
-  assign(Str $name, Str | CodeRef $code, Any @args) (Any)
+  assign(string $name, string | coderef $code, any @args) (any)
 
 The assign method dispatches the method call or executes the callback, sets the
 class attribute specified to the result, and returns the result.
@@ -242,7 +242,7 @@ Awncorp, C<awncorp@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2000, Al Newkirk.
+Copyright (C) 2000, Awncorp, C<awncorp@cpan.org>.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Apache license version 2.0.
