@@ -101,7 +101,7 @@ This package provides the following methods:
 
 =head2 catch
 
-  catch(Str $method, Any @args) (Any)
+  catch(string $method, any @args) (any)
 
 The catch method traps any errors raised by executing the dispatched method
 call and returns the error string or error object. This method can return a
@@ -171,7 +171,7 @@ I<Since C<0.01>>
 
 =head2 maybe
 
-  maybe(Str $method, Any @args) (Any)
+  maybe(string $method, any @args) (any)
 
 The maybe method traps any errors raised by executing the dispatched method
 call and returns undefined on error, effectively supressing the error. This
@@ -233,7 +233,7 @@ Awncorp, C<awncorp@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2000, Al Newkirk.
+Copyright (C) 2000, Awncorp, C<awncorp@cpan.org>.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Apache license version 2.0.
