@@ -91,7 +91,7 @@ This package provides the following methods:
 
 =head2 defer
 
-  defer(Str $method, Any @args) (CodeRef)
+  defer(string $method, any @args) (coderef)
 
 The defer method returns the named method as a callback (i.e. closure) which
 dispatches to the method call specified.
@@ -168,7 +168,7 @@ Awncorp, C<awncorp@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2000, Al Newkirk.
+Copyright (C) 2000, Awncorp, C<awncorp@cpan.org>.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Apache license version 2.0.
