@@ -103,7 +103,7 @@ This package provides the following methods:
 
 =head2 build_proxy
 
-  build_proxy(Str $package, Str $method, Any @args) (CodeRef | Undef)
+  build_proxy(string $package, string $method, any @args) (coderef | undef)
 
 The build_proxy method should return a code reference to fulfill the method
 dispatching request, or undef to result in a method not found error.
@@ -148,7 +148,7 @@ Awncorp, C<awncorp@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2000, Al Newkirk.
+Copyright (C) 2000, Awncorp, C<awncorp@cpan.org>.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Apache license version 2.0.
