@@ -78,7 +78,7 @@ This package provides the following methods:
 
 =head2 unpack
 
-  unpack(Any @args) (Venus::Unpack)
+  unpack(any @args) (Venus::Unpack)
 
 The unpack method passes the arguments provided to L<Venus::Unpack> for
 unpacking and validating arbitrary argument lists.
@@ -146,7 +146,7 @@ Awncorp, C<awncorp@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2000, Al Newkirk.
+Copyright (C) 2000, Awncorp, C<awncorp@cpan.org>.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Apache license version 2.0.
